@@ -19,9 +19,13 @@ class Backtracking(BaseSolver):
         solution.append(current)
 
         # pick a random neighbor and travel to it, until you're at the end
+        max_count = max(self.maze.height, self.maze.width) * 10000
+        count = 0
         while not self._within_one(solution[-1], self.end):
             ns = self._find_unblocked_neighbors(solution[-1])
-
+            if count >= max_count:
+                raise ValueError("solving time exceeds the max time.")
+            count += 1
             # do no go where you've just been
             if len(ns) > 1 and len(solution) > 2:
                 if solution[-3] in ns:
